@@ -35,6 +35,7 @@
 #include "misc.h"
 #include "sound.h"
 #include "string.h"
+#include "partyline.h"
 
 extern GConfClient *gconf_client;
 extern GtkWidget *app;
@@ -56,7 +57,7 @@ void connectingdialog_button (GtkWidget *dialog, gint button)
         gtk_timeout_remove (timeouttag);
         timeouttag = 0;
         if (connectingdialog == 0) return;
-        client_connectcancel ();
+        client_disconnect ();
         gtk_widget_destroy (connectingdialog);
         connectingdialog = 0;
         break;
@@ -142,7 +143,7 @@ void teamdialog_button (GtkWidget *button, gint response, gpointer data)
 
 void teamdialog_new (void)
 {
-    GtkWidget *hbox, *buttonbox, *widget, *entry;
+    GtkWidget *hbox, *widget, *entry;
     gchar *team_utf8 = g_locale_to_utf8 (team, -1, NULL, NULL, NULL);
   
     if (team_dialog != NULL)
@@ -507,6 +508,7 @@ gint key_dialog (char *msg)
 /* the preferences dialog */
 /**************************/
 GtkWidget *themelist, *keyclist;
+GtkWidget *timestampcheck;
 GtkWidget *midientry, *miditable, *midicheck, *soundcheck;
 GtkWidget *namelabel, *authlabel, *desclabel;
 
@@ -669,6 +671,12 @@ void prefdialog_restoremidi (void)
                              NULL);
 }
 
+void prefdialog_timestampstoggle (GtkWidget *widget)
+{
+    gconf_client_set_bool (gconf_client, "/apps/gtetrinet/partyline/enable_timestamps",
+                           GTK_TOGGLE_BUTTON (widget)->active, NULL);
+}
+
 void prefdialog_themelistselect (int n)
 {
     char author[1024], desc[1024];
@@ -757,7 +765,7 @@ void prefdialog_themelist ()
         text[1] = 0;
         gtk_list_store_append (theme_store, &iter);
         gtk_list_store_set (theme_store, &iter, 0, themes[i].name, 1, i, -1);
-        if (strcmp (themes[i].dir, currenttheme) == 0)
+        if (strcmp (themes[i].dir, currenttheme->str) == 0)
         {
             iter_selected = iter;
             theme_select = i;
@@ -773,6 +781,9 @@ void prefdialog_themelist ()
 void prefdialog_response (GtkDialog *dialog,
                           gint arg1)
 {
+
+  dialog = dialog;	/* Supress compile warning */
+
   switch (arg1)
   {
     case GTK_RESPONSE_CLOSE: prefdialog_destroy (); break;
@@ -788,7 +799,6 @@ void prefdialog_new (void)
     GtkListStore *keys_store = gtk_list_store_new (4, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_INT, G_TYPE_STRING);
     GtkCellRenderer *renderer = gtk_cell_renderer_text_new ();
     GtkTreeSelection *theme_selection;
-    int i;
   
     if (prefdialog != NULL)
     {
@@ -876,6 +886,32 @@ void prefdialog_new (void)
     gtk_widget_show (label);
     gtk_notebook_append_page (GTK_NOTEBOOK (notebook), table, label);
 
+    /* partyline */
+    timestampcheck = gtk_check_button_new_with_label (_("Enable Timestamps"));
+    gtk_widget_show(timestampcheck);
+
+    frame = gtk_hbox_new (FALSE, 0);
+    gtk_box_pack_start (GTK_BOX(frame), timestampcheck, FALSE, FALSE, 0);
+    gtk_widget_show (frame);
+
+    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(timestampcheck),
+                                  timestampsenable);
+
+    g_signal_connect (G_OBJECT(timestampcheck), "toggled",
+                      G_CALLBACK(prefdialog_timestampstoggle), NULL);
+
+    table = gtk_table_new (3, 1, FALSE);
+    gtk_container_set_border_width (GTK_CONTAINER(table), GNOME_PAD);
+    gtk_table_set_row_spacings (GTK_TABLE(table), GNOME_PAD_SMALL);
+    gtk_table_set_col_spacings (GTK_TABLE(table), GNOME_PAD_SMALL);
+    gtk_table_attach (GTK_TABLE(table), frame, 0, 1, 0, 1,
+                      GTK_EXPAND | GTK_FILL, 0, 0, 0);
+    gtk_widget_show (table);
+
+    label = gtk_label_new (_("Partyline"));
+    gtk_widget_show (label);
+    gtk_notebook_append_page (GTK_NOTEBOOK (notebook), table, label);
+
     /* keyboard */
     keyclist = GTK_WIDGET (gtk_tree_view_new_with_model (GTK_TREE_MODEL(keys_store)));
     key_scroll = gtk_scrolled_window_new (NULL, NULL);
