@@ -73,6 +73,7 @@ void fields_init (void)
                                       "Falling back to default"));
         gtk_dialog_run (GTK_DIALOG (mb));
         gtk_widget_destroy (mb);
+	g_string_assign(currenttheme, DEFAULTTHEME);
         config_loadtheme (DEFAULTTHEME);
         err = NULL;
         if (!(pb = gdk_pixbuf_new_from_file(blocksfile, &err))) {
@@ -99,7 +100,7 @@ GtkWidget *fields_page_new (void)
     pagecontents = fields_page_contents ();
 
     if (fieldspage == NULL) {
-        fieldspage = gtk_alignment_new (0.5, 0.5, 0.0, 0.0);
+        fieldspage = gtk_alignment_new (0.5, 0.5, 1.0, 1.0);
         gtk_container_set_border_width (GTK_CONTAINER(fieldspage), 2);
     }
     gtk_container_add (GTK_CONTAINER(fieldspage), pagecontents);
@@ -305,7 +306,7 @@ GtkWidget *fields_page_contents (void)
     
     align = gtk_alignment_new (0.5, 0.5, 0.0, 0.0);
     gtk_container_add (GTK_CONTAINER (align), table);
-    gtk_box_pack_start (GTK_BOX (vbox), align, TRUE, TRUE, 0);
+    gtk_box_pack_start (GTK_BOX (vbox), align, FALSE, FALSE, 0);
     align = gtk_alignment_new (0.5, 0.5, 1.0, 1.0);
     gtk_container_add (GTK_CONTAINER (align), table2);
     gtk_box_pack_start (GTK_BOX (vbox), align, TRUE, TRUE, 0);
@@ -457,10 +458,10 @@ void fields_drawspecials (void)
     int i;
     for (i = 0; i < 18; i ++) {
         if (i < specialblocknum) {
-            gdk_draw_pixmap (specialwidget->window,
-                             specialwidget->style->black_gc,
-                             blockpix, (specialblocks[i]-1)*BLOCKSIZE,
-                             0, BLOCKSIZE*i, 0, BLOCKSIZE, BLOCKSIZE);
+            gdk_draw_drawable (specialwidget->window,
+                               specialwidget->style->black_gc,
+                               blockpix, (specialblocks[i]-1)*BLOCKSIZE,
+                               0, BLOCKSIZE*i, 0, BLOCKSIZE, BLOCKSIZE);
         }
         else {
             gdk_draw_rectangle (specialwidget->window, specialwidget->style->black_gc,
@@ -485,12 +486,12 @@ void fields_drawnextblock (TETRISBLOCK block)
     for (y = ystart; y < 4; y ++)
         for (x = xstart; x < 4; x ++) {
             if (block[y][x]) {
-                gdk_draw_pixmap (nextpiecewidget->window,
-                                 nextpiecewidget->style->black_gc,
-                                 blockpix, (block[y][x]-1)*BLOCKSIZE, 0,
-                                 BLOCKSIZE*(x-xstart)+BLOCKSIZE/4,
-                                 BLOCKSIZE*(y-ystart)+BLOCKSIZE/4,
-                                 BLOCKSIZE, BLOCKSIZE);
+                gdk_draw_drawable (nextpiecewidget->window,
+                                   nextpiecewidget->style->black_gc,
+                                   blockpix, (block[y][x]-1)*BLOCKSIZE, 0,
+                                   BLOCKSIZE*(x-xstart)+BLOCKSIZE/4,
+                                   BLOCKSIZE*(y-ystart)+BLOCKSIZE/4,
+                                   BLOCKSIZE, BLOCKSIZE);
             }
         }
     memcpy (displayblock, block, 16);
@@ -603,6 +604,8 @@ void gmsginput_activate (void)
             /* post /me thingy */
             g_snprintf (buf, sizeof(buf), "* %s %s", nick, s+4);
             locale_s = g_locale_from_utf8 (buf, -1, NULL, NULL, NULL);
+			/* FIXME : if there is an error while converting from UTF8 to current locale, we ignore the message */
+			if (locale_s == NULL) return;
             client_outmessage (OUT_GMSG, locale_s);
             g_free (locale_s);
         }
@@ -610,6 +613,8 @@ void gmsginput_activate (void)
             /* post message */
             g_snprintf (buf, sizeof(buf), "<%s> %s", nick, s);
             locale_s = g_locale_from_utf8 (buf, -1, NULL, NULL, NULL);
+			/* FIXME : if there is an error while converting from UTF8 to current locale, we ignore the message */
+			if (locale_s == NULL) return;
             client_outmessage (OUT_GMSG, locale_s);
             g_free (locale_s);
         }
