@@ -99,62 +99,8 @@ static int gtetrinet_poll_func(GPollFD *passed_fds,
 int main (int argc, char *argv[])
 {
     GtkWidget *label;
-    char buf[1024];
     GdkPixbuf *icon_pixbuf;
     GError *err = NULL;
-
-    GTET_STRCPY(buf, "", 4);
-    g_assert(strlen(buf) == 0);
-    g_assert(buf[0] == 0);
-    
-    GTET_STRCAT(buf, "", 4);
-    g_assert(strlen(buf) == 0);
-    g_assert(buf[0] == 0);
-    
-    GTET_STRCPY(buf, "a", 1);
-    g_assert(strlen(buf) == 0);
-    g_assert(buf[0] == 0);
-    
-    GTET_STRCAT(buf, "a", 1);
-    g_assert(strlen(buf) == 0);
-    g_assert(buf[0] == 0);
-    
-    GTET_STRCPY(buf, "abcd", 4);
-    g_assert(strlen(buf) == 3);
-    g_assert(buf[3] == 0);
-    g_assert(buf[2] == 'c');
-    g_assert(buf[1] == 'b');
-    g_assert(buf[0] == 'a');
-    
-    GTET_STRCAT(buf, "xyz", 4);    
-    g_assert(strlen(buf) == 3);
-    g_assert(buf[3] == 0);
-    g_assert(buf[2] == 'c');
-    g_assert(buf[1] == 'b');
-    g_assert(buf[0] == 'a');
-    
-    GTET_STRCAT(buf, "abcd", 7);    
-    g_assert(strlen(buf) == 6);
-    g_assert(buf[6] == 0);
-    g_assert(buf[5] == 'c');
-    g_assert(buf[4] == 'b');
-    g_assert(buf[3] == 'a');
-    g_assert(buf[2] == 'c');
-    g_assert(buf[1] == 'b');
-    g_assert(buf[0] == 'a');
-    
-    GTET_O_STRCPY(buf, "abcd");
-    GTET_O_STRCAT(buf, "abcd");
-    g_assert(strlen(buf) == 8);
-    g_assert(buf[8] == 0);
-    g_assert(buf[7] == 'd');
-    g_assert(buf[6] == 'c');
-    g_assert(buf[5] == 'b');
-    g_assert(buf[4] == 'a');
-    g_assert(buf[3] == 'd');
-    g_assert(buf[2] == 'c');
-    g_assert(buf[1] == 'b');
-    g_assert(buf[0] == 'a');
     
     bindtextdomain(PACKAGE, LOCALEDIR);
     bind_textdomain_codeset(PACKAGE, "UTF-8");
@@ -162,7 +108,6 @@ int main (int argc, char *argv[])
 
     srand (time(NULL));
 
-    //gnome_init_with_popt_table (APPID, APPVERSION, argc, argv, options, 0 , NULL);
     gnome_program_init (APPID, APPVERSION, LIBGNOMEUI_MODULE,
 	                      argc, argv, GNOME_PARAM_POPT_TABLE, options,
 				                GNOME_PARAM_NONE);
@@ -190,6 +135,9 @@ int main (int argc, char *argv[])
     gconf_client_add_dir (gconf_client, "/apps/gtetrinet/keys",
                           GCONF_CLIENT_PRELOAD_ONELEVEL, NULL);
 
+    gconf_client_add_dir (gconf_client, "/apps/gtetrinet/partyline",
+                          GCONF_CLIENT_PRELOAD_ONELEVEL, NULL);
+
     /* Request notification of change for these gconf keys */
     gconf_client_notify_add (gconf_client, "/apps/gtetrinet/sound/midi_player",
                              (GConfClientNotifyFunc) sound_midi_player_changed,
@@ -238,12 +186,16 @@ int main (int argc, char *argv[])
                              (GConfClientNotifyFunc) keys_message_changed,
 			     NULL, NULL, NULL);
 
+    gconf_client_notify_add (gconf_client, "/apps/gtetrinet/partyline/enable_timestamps",
+                             (GConfClientNotifyFunc) partyline_enable_timestamps_changed,
+			     NULL, NULL, NULL);
+
     /* load settings */
     config_loadconfig ();
 
     /* initialise some stuff */
-    client_initpipes ();
     fields_init ();
+    if (!g_thread_supported()) g_thread_init (NULL);
 
     /* first set up the display */
 
@@ -353,10 +305,9 @@ int main (int argc, char *argv[])
     /* gtk_main() */
     gtk_main ();
 
+    client_disconnect ();
     /* cleanup */
-    client_destroypipes ();
     fields_cleanup ();
-    client_connectcancel (); /* kills the client process */
     sound_stopmidi ();
 
     return 0;
